package com.totopia.server.modules.game.controller;

import com.totopia.server.commons.data.payload.ApiResponse;
import com.totopia.server.modules.game.entity.LeagueEntity;
import com.totopia.server.modules.game.service.LeagueService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.web.SortDefault;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@RestController
public class LeagueController {

    @Autowired
    private LeagueService leagueService;

    @GetMapping(value = "/league")
    public Page<LeagueEntity> all(
        @SortDefault.SortDefaults({
            @SortDefault(
                sort = "createdAt",
                direction = Sort.Direction.DESC) })
            Pageable pageable) {
        return this.leagueService.getAllLeagueByPageable(pageable);
    }

    @GetMapping(value = "/league/{sprotName}")
    public ResponseEntity<LeagueEntity> findBySportsName(@PathVariable String sportName) {
        return null;
    }

    @PostMapping(value = "/league")
    @ResponseStatus(code = HttpStatus.CREATED)
    public ResponseEntity<?> save(@Valid @RequestBody LeagueEntity leagueEntity) throws Exception{
        this.leagueService.save(leagueEntity);
        return ResponseEntity.ok().body(new ApiResponse(true, "League registered successfully"));
    }

    @PutMapping(value = "/league/{leagueId}")
    public ResponseEntity<?> updateLeague(@PathVariable Long leagueId, LeagueEntity leagueEntity) throws Exception {
        LeagueEntity leagueEntity1 = this.leagueService.modify(leagueEntity);
        return ResponseEntity.ok(leagueEntity1);
    }

    @DeleteMapping(value = "/league/{leagueId}")
    public ResponseEntity<?> deleteLeague(@PathVariable Long leagueId) {
        Long res = this.leagueService.removeById(leagueId);
        return ResponseEntity.ok(res);
    }
}
