package com.totopia.server.modules.site.controller;

import com.totopia.server.commons.data.payload.ApiResponse;
import com.totopia.server.modules.game.entity.LeagueEntity;
import com.totopia.server.modules.site.entity.BankInfoEntity;
import com.totopia.server.modules.site.service.BankInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.data.web.SortDefault;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RestController
public class BankInfoController {

  @Autowired
  BankInfoService bankInfoService;

  @GetMapping(value = "/bank_info")
  public Page<BankInfoEntity> all(
      @SortDefault.SortDefaults({
          @SortDefault(
              sort = "id",
              direction = Sort.Direction.ASC) })
          Pageable pageable) {
    return this.bankInfoService.getAllBankInfo(pageable);
  }

  @GetMapping(value = "/bank_info/test")
  public List<BankInfoEntity> allTest() {

    return this.bankInfoService.getAllBankInfoTest();
  }


  @PostMapping(value = "/bank_info")
  @ResponseStatus(code = HttpStatus.CREATED)
  public ResponseEntity<?> save(@Valid @RequestBody BankInfoEntity bankInfoEntity) throws Exception{
    this.bankInfoService.save(bankInfoEntity);
    return ResponseEntity.ok().body(new ApiResponse(true, "BankInfo registered successfully"));
  }

  @PutMapping(value = "/bank_info/{bankInfoId}")
  public ResponseEntity<?> updateLeague(@PathVariable Long bankInfoId, BankInfoEntity bankInfoEntity) throws Exception {
    BankInfoEntity leagueEntity1 = this.bankInfoService.modify(bankInfoEntity);
    return ResponseEntity.ok(leagueEntity1);
  }
}
